import { api } from "@nice/client";
import { TaxonomySlug } from "@nice/common";
import { useMemo } from "react";

export function useNavItem() {
    const { data } = api.term.findMany.useQuery({
        where: {
            taxonomy: { slug: TaxonomySlug.CATEGORY }
        }
    });

    const navItems = useMemo(() => {
        // 定义固定的导航项
        const staticItems = {
            letterList: { to: "/", label: "公开信件" },
            letterProgress: { to: "/letter-progress", label: "进度查询" },
            help: { to: "/help", label: "使用帮助" }
        };

        if (!data) {
            return [staticItems.letterList, staticItems.letterProgress, staticItems.help];
        }

        // 构建分类导航项
        const categoryItems = data.map(term => ({
            to: `/write-letter?termId=${term.id}`,
            label: term.name
        }));

        // 按照指定顺序返回导航项
        return [
            staticItems.letterList,
            ...categoryItems,
            staticItems.letterProgress,
            staticItems.help
        ];
    }, [data]);

    return { navItems };
}
