import { PostDto, VisitType } from "@nice/common";
import { useVisitor } from "@nice/client";
import { useContext } from "react";
import { PostDetailContext } from "../context/PostDetailContext";
import { Button, Tooltip } from "antd";
import { LikeFilled, LikeOutlined } from "@ant-design/icons";

export default function PostLikeButton({ post }: { post: PostDto }) {
	const { user } = useContext(PostDetailContext);
	const { like, unLike } = useVisitor();

	function likeThisPost() {
		if (!post?.liked) {
			post.likes += 1;
			post.liked = true;
			like.mutateAsync({
				data: {
					visitorId: user?.id || null,
					postId: post.id,
					type: VisitType.LIKE,
				},
			});
		} else {
			post.likes -= 1;
			post.liked = false;
			unLike.mutateAsync({
				where: {
					visitorId: user?.id || null,
					postId: post.id,
					type: VisitType.LIKE,
				},
			});
		}
	}
	return (
		<Tooltip title={post?.liked ? "取消点赞" : "点赞"} placement="top">
			<Button
				type={post?.liked ? "primary" : "default"}
				shape="round"
				size="small"
				icon={post?.liked ? <LikeFilled /> : <LikeOutlined />}
				onClick={likeThisPost}
				className={`
                        flex items-center gap-1 px-3 transform transition-all duration-300
                        hover:scale-105 hover:shadow-md
                        ${post?.liked ? "bg-blue-500 hover:bg-blue-600" : "hover:border-blue-500 hover:text-blue-500"}
                    `}>
				<span className={post?.liked ? "text-white" : ""}>
					{post?.likes}
				</span>
			</Button>
		</Tooltip>
	);
}
